""" openconfig_transport_line_protection 

This model describes configuration and operational state data
for optical line protection elements, deployed as part of a
transport line system. An Automatic Protection Switch (APS)
is typically installed in the same device as the amplifiers
and wave\-router, however an APS can also be a standalone
device. In both scenarios, it serves the same purpose of
providing protection using two dark fiber pairs to ensure the
amplifiers can still receive a signal if one of the two fiber
pairs is broken. The APS port details and directionality are
shown below. The three major attributes, together with their
modifiers, define the behavior of the APS and can be prioritized
in the descending order as shown in the following table

"""
from collections import OrderedDict

from ydk.types import Entity as _Entity_
from ydk.types import EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class APSPATHS(Identity):
    """
    Base identity for identifying the line paths on an
    automatic protection switch
    
    """
    _prefix = 'oc-line-protect'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/optical-transport-line-protection", pref="openconfig-transport-line-protection", tag="openconfig-transport-line-protection:APS_PATHS"):
        super().__init__(ns, pref, tag)


class Aps(_Entity_):
    """
    Top level grouping for automatic protection switch data
    
    .. attribute:: aps_modules
    
        Enclosing container for list of automatic protection       switch modules
    
        **type**:  :py:class:`ApsModules<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules>`
    
    """
    _prefix = 'oc-line-protect'
    _revision = '2018-11-21'

    def __init__(self):
        super().__init__()
        self._top_entity = None

        self.yang_name = "aps"
        self.yang_parent_name = "openconfig-transport-line-protection"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("aps-modules", ("aps_modules", Aps.ApsModules))])
        self._leafs = OrderedDict()

        self.aps_modules = Aps.ApsModules()
        self.aps_modules.parent = self
        self._children_name_map["aps_modules"] = "aps-modules"
        self._segment_path = lambda: "openconfig-transport-line-protection:aps"
        self._is_frozen = True

    def __setattr__(self, name, value):
        self._perform_setattr(Aps, [], name, value)

    class ApsModules(_Entity_):
        """
        Enclosing container for list of automatic protection
              switch modules
        
        .. attribute:: aps_module
        
            List of automatic protection switch modules present in the device
        
            **type**: list of    :py:class:`ApsModule<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule>`
        
        """
        _prefix = 'oc-line-protect'
        _revision = '2018-11-21'

        def __init__(self):
            super().__init__()

            self.yang_name = "aps-modules"
            self.yang_parent_name = "aps"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("aps-module", ("aps_module", Aps.ApsModules.ApsModule))])
            self._leafs = OrderedDict()

            self.aps_module = YList(self)
            self._segment_path = lambda: "aps-modules"
            self._absolute_path = lambda: "openconfig-transport-line-protection:aps/%s" % self._segment_path()
            self._is_frozen = True

        def __setattr__(self, name, value):
            self._perform_setattr(Aps.ApsModules, [], name, value)

        class ApsModule(_Entity_):
            """
            List of automatic protection switch modules present
            in the device
            
            .. attribute:: name  (key)
            
                Reference to the config name list key
            
                **type**: str
            
                **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Config>`
            
            .. attribute:: config
            
                Configuration data for an automatic protection switch module
            
                **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Config>`
            
            .. attribute:: state
            
                Operational state data for an automatic protection switch module
            
                **type**:  :py:class:`State<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.State>`
            
                **config**: False
            
            .. attribute:: ports
            
                Top level grouping for automatic protection switch ports
            
                **type**:  :py:class:`Ports<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports>`
            
            """
            _prefix = 'oc-line-protect'
            _revision = '2018-11-21'

            def __init__(self):
                super().__init__()

                self.yang_name = "aps-module"
                self.yang_parent_name = "aps-modules"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['name']
                self._child_classes = OrderedDict([("config", ("config", Aps.ApsModules.ApsModule.Config)), ("state", ("state", Aps.ApsModules.ApsModule.State)), ("ports", ("ports", Aps.ApsModules.ApsModule.Ports))])
                self._leafs = OrderedDict([
                    ('name', (YLeaf(YType.str, 'name'), ['str'])),
                ])
                self.name = None

                self.config = Aps.ApsModules.ApsModule.Config()
                self.config.parent = self
                self._children_name_map["config"] = "config"

                self.state = Aps.ApsModules.ApsModule.State()
                self.state.parent = self
                self._children_name_map["state"] = "state"

                self.ports = Aps.ApsModules.ApsModule.Ports()
                self.ports.parent = self
                self._children_name_map["ports"] = "ports"
                self._segment_path = lambda: "aps-module" + "[name='" + str(self.name) + "']"
                self._absolute_path = lambda: "openconfig-transport-line-protection:aps/aps-modules/%s" % self._segment_path()
                self._is_frozen = True

            def __setattr__(self, name, value):
                self._perform_setattr(Aps.ApsModules.ApsModule, ['name'], name, value)

            class Config(_Entity_):
                """
                Configuration data for an automatic protection
                switch module
                
                .. attribute:: name
                
                    Reference to the component name (in the platform model) corresponding to this automatic protection switch module in the device
                
                    **type**: str
                
                    **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_platform.Components.Component>`
                
                .. attribute:: revertive
                
                    Revertive behavior of the module. If True, then automatically revert after protection switch once the fault is restored. This leaf is not valid when the relative\-switch\-threshold is in effect
                
                    **type**: bool
                
                .. attribute:: wait_to_restore_time
                
                    The time that must elapse before an APS path that has recovered from an signal failure (SF) or signal degradation (SD) condition can be used again to transport the normal traffic signal. During this time period, an SF or SD condition shall override the wait\-to\-restore time period. This leaf can only take effect when the revertive leaf equals true
                
                    **type**: int
                
                        **range:** 0..4294967295
                
                    **units**: milliseconds
                
                .. attribute:: hold_off_time
                
                    The time delay between the declaration of an SF or SD condition and the initiation of the protection switching algorithm
                
                    **type**: int
                
                        **range:** 0..4294967295
                
                    **units**: milliseconds
                
                .. attribute:: primary_switch_threshold
                
                    The threshold at which the primary line port will switch to the opposite line port in increments of 0.01 dBm. If the hardware supports only one switch threshold for primary and and secondary ports then it is recommended to set both primary\-switch\-threshold and secondary\-switch\-threshold to the same value to be explicit. When the relative switch threshold is enabled, i.e. set to a non\-zero value, the primary switch threshold will be overridden
                
                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                
                        **range:** \-92233720368547758.08..92233720368547758.07
                
                    **units**: dBm
                
                .. attribute:: primary_switch_hysteresis
                
                    The delta in dB between the primary\-switch\-threshold and the signal received on the primary APS\_PATH before initiating a switch from the secondary APS\_PATH to the primary APS\_PATH, in order to prevent toggling between ports when an input signal is very close to the threshold. A zero value means the switch hysteresis is disabled
                
                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                
                        **range:** \-92233720368547758.08..92233720368547758.07
                
                    **units**: dB
                
                    **default value**: 0
                
                .. attribute:: secondary_switch_threshold
                
                    The threshold at which the secondary line port will switch to the opposite line port in increments of 0.01 dBm. If the hardware supports only one switch threshold for primary and and secondary ports then it is recommended to set both primary\-switch\-threshold and secondary\-switch\-threshold to the same value to be explicit. When the relative switch threshold is enabled, i.e. set to a non\-zero value, the secondary switch threshold will be overridden
                
                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                
                        **range:** \-92233720368547758.08..92233720368547758.07
                
                    **units**: dBm
                
                .. attribute:: relative_switch_threshold
                
                    The delta threshold in dB at which the current line port will switch to the opposite line port. It can be set to the value of 0dB. When set to 0dB, the threshold is ignored and the system automatically applies the primary and secondary switch thresholds. When set to a non\-zero value, it overrides the primary and secondary switch thresholds
                
                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                
                        **range:** \-92233720368547758.08..92233720368547758.07
                
                    **units**: dB
                
                    **default value**: 0
                
                .. attribute:: relative_switch_threshold_offset
                
                    The offset of the relative switch threshold that compensates the normal difference of receiving power between the primary and secondary line ports. A negative offset corresponds to the situation where the secondary line port receives a higher power than the primary line port in normal condition, and a positive offset means the opposite. The offset will only work when the relative switch threshold is set to a non\-zero value
                
                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                
                        **range:** \-92233720368547758.08..92233720368547758.07
                
                    **units**: dB
                
                    **default value**: 0
                
                .. attribute:: force_to_port
                
                    Explicitly set the switch to stay on a port regardless of its operational condition
                
                    **type**:  :py:class:`ForceToPort<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Config.ForceToPort>`
                
                    **default value**: NONE
                
                """
                _prefix = 'oc-line-protect'
                _revision = '2018-11-21'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "config"
                    self.yang_parent_name = "aps-module"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('revertive', (YLeaf(YType.boolean, 'revertive'), ['bool'])),
                        ('wait_to_restore_time', (YLeaf(YType.uint32, 'wait-to-restore-time'), ['int'])),
                        ('hold_off_time', (YLeaf(YType.uint32, 'hold-off-time'), ['int'])),
                        ('primary_switch_threshold', (YLeaf(YType.str, 'primary-switch-threshold'), ['Decimal64'])),
                        ('primary_switch_hysteresis', (YLeaf(YType.str, 'primary-switch-hysteresis'), ['Decimal64'])),
                        ('secondary_switch_threshold', (YLeaf(YType.str, 'secondary-switch-threshold'), ['Decimal64'])),
                        ('relative_switch_threshold', (YLeaf(YType.str, 'relative-switch-threshold'), ['Decimal64'])),
                        ('relative_switch_threshold_offset', (YLeaf(YType.str, 'relative-switch-threshold-offset'), ['Decimal64'])),
                        ('force_to_port', (YLeaf(YType.enumeration, 'force-to-port'), [('ydk.models.openconfig.openconfig_transport_line_protection', 'Aps', 'ApsModules.ApsModule.Config.ForceToPort')])),
                    ])
                    self.name = None
                    self.revertive = None
                    self.wait_to_restore_time = None
                    self.hold_off_time = None
                    self.primary_switch_threshold = None
                    self.primary_switch_hysteresis = None
                    self.secondary_switch_threshold = None
                    self.relative_switch_threshold = None
                    self.relative_switch_threshold_offset = None
                    self.force_to_port = None
                    self._segment_path = lambda: "config"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Aps.ApsModules.ApsModule.Config, ['name', 'revertive', 'wait_to_restore_time', 'hold_off_time', 'primary_switch_threshold', 'primary_switch_hysteresis', 'secondary_switch_threshold', 'relative_switch_threshold', 'relative_switch_threshold_offset', 'force_to_port'], name, value)

                class ForceToPort(Enum):
                    """
                    ForceToPort (Enum Class)

                    .. data:: NONE = 0

                        Do not force the switch to stay on any line port

                    .. data:: PRIMARY = 1

                        Force the switch to stay on the primary line port

                    .. data:: SECONDARY = 2

                        Force the switch to stay on the secondary line port

                    """

                    NONE = Enum.YLeaf(0, "NONE")

                    PRIMARY = Enum.YLeaf(1, "PRIMARY")

                    SECONDARY = Enum.YLeaf(2, "SECONDARY")



            class State(_Entity_):
                """
                Operational state data for an automatic protection
                switch module
                
                .. attribute:: name
                
                    Reference to the component name (in the platform model) corresponding to this automatic protection switch module in the device
                
                    **type**: str
                
                    **refers to**:  :py:class:`name<ydk.models.openconfig.openconfig_platform.Components.Component>`
                
                    **config**: False
                
                .. attribute:: revertive
                
                    Revertive behavior of the module. If True, then automatically revert after protection switch once the fault is restored. This leaf is not valid when the relative\-switch\-threshold is in effect
                
                    **type**: bool
                
                    **config**: False
                
                .. attribute:: wait_to_restore_time
                
                    The time that must elapse before an APS path that has recovered from an signal failure (SF) or signal degradation (SD) condition can be used again to transport the normal traffic signal. During this time period, an SF or SD condition shall override the wait\-to\-restore time period. This leaf can only take effect when the revertive leaf equals true
                
                    **type**: int
                
                        **range:** 0..4294967295
                
                    **config**: False
                
                    **units**: milliseconds
                
                .. attribute:: hold_off_time
                
                    The time delay between the declaration of an SF or SD condition and the initiation of the protection switching algorithm
                
                    **type**: int
                
                        **range:** 0..4294967295
                
                    **config**: False
                
                    **units**: milliseconds
                
                .. attribute:: primary_switch_threshold
                
                    The threshold at which the primary line port will switch to the opposite line port in increments of 0.01 dBm. If the hardware supports only one switch threshold for primary and and secondary ports then it is recommended to set both primary\-switch\-threshold and secondary\-switch\-threshold to the same value to be explicit. When the relative switch threshold is enabled, i.e. set to a non\-zero value, the primary switch threshold will be overridden
                
                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                
                        **range:** \-92233720368547758.08..92233720368547758.07
                
                    **config**: False
                
                    **units**: dBm
                
                .. attribute:: primary_switch_hysteresis
                
                    The delta in dB between the primary\-switch\-threshold and the signal received on the primary APS\_PATH before initiating a switch from the secondary APS\_PATH to the primary APS\_PATH, in order to prevent toggling between ports when an input signal is very close to the threshold. A zero value means the switch hysteresis is disabled
                
                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                
                        **range:** \-92233720368547758.08..92233720368547758.07
                
                    **config**: False
                
                    **units**: dB
                
                    **default value**: 0
                
                .. attribute:: secondary_switch_threshold
                
                    The threshold at which the secondary line port will switch to the opposite line port in increments of 0.01 dBm. If the hardware supports only one switch threshold for primary and and secondary ports then it is recommended to set both primary\-switch\-threshold and secondary\-switch\-threshold to the same value to be explicit. When the relative switch threshold is enabled, i.e. set to a non\-zero value, the secondary switch threshold will be overridden
                
                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                
                        **range:** \-92233720368547758.08..92233720368547758.07
                
                    **config**: False
                
                    **units**: dBm
                
                .. attribute:: relative_switch_threshold
                
                    The delta threshold in dB at which the current line port will switch to the opposite line port. It can be set to the value of 0dB. When set to 0dB, the threshold is ignored and the system automatically applies the primary and secondary switch thresholds. When set to a non\-zero value, it overrides the primary and secondary switch thresholds
                
                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                
                        **range:** \-92233720368547758.08..92233720368547758.07
                
                    **config**: False
                
                    **units**: dB
                
                    **default value**: 0
                
                .. attribute:: relative_switch_threshold_offset
                
                    The offset of the relative switch threshold that compensates the normal difference of receiving power between the primary and secondary line ports. A negative offset corresponds to the situation where the secondary line port receives a higher power than the primary line port in normal condition, and a positive offset means the opposite. The offset will only work when the relative switch threshold is set to a non\-zero value
                
                    **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                
                        **range:** \-92233720368547758.08..92233720368547758.07
                
                    **config**: False
                
                    **units**: dB
                
                    **default value**: 0
                
                .. attribute:: force_to_port
                
                    Explicitly set the switch to stay on a port regardless of its operational condition
                
                    **type**:  :py:class:`ForceToPort<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.State.ForceToPort>`
                
                    **config**: False
                
                    **default value**: NONE
                
                .. attribute:: active_path
                
                    Indicates which line path on the protection switch is currently the active path connected to the common port
                
                    **type**:  :py:class:`APSPATHS<ydk.models.openconfig.openconfig_transport_line_protection.APSPATHS>`
                
                    **config**: False
                
                """
                _prefix = 'oc-line-protect'
                _revision = '2018-11-21'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "state"
                    self.yang_parent_name = "aps-module"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('name', (YLeaf(YType.str, 'name'), ['str'])),
                        ('revertive', (YLeaf(YType.boolean, 'revertive'), ['bool'])),
                        ('wait_to_restore_time', (YLeaf(YType.uint32, 'wait-to-restore-time'), ['int'])),
                        ('hold_off_time', (YLeaf(YType.uint32, 'hold-off-time'), ['int'])),
                        ('primary_switch_threshold', (YLeaf(YType.str, 'primary-switch-threshold'), ['Decimal64'])),
                        ('primary_switch_hysteresis', (YLeaf(YType.str, 'primary-switch-hysteresis'), ['Decimal64'])),
                        ('secondary_switch_threshold', (YLeaf(YType.str, 'secondary-switch-threshold'), ['Decimal64'])),
                        ('relative_switch_threshold', (YLeaf(YType.str, 'relative-switch-threshold'), ['Decimal64'])),
                        ('relative_switch_threshold_offset', (YLeaf(YType.str, 'relative-switch-threshold-offset'), ['Decimal64'])),
                        ('force_to_port', (YLeaf(YType.enumeration, 'force-to-port'), [('ydk.models.openconfig.openconfig_transport_line_protection', 'Aps', 'ApsModules.ApsModule.State.ForceToPort')])),
                        ('active_path', (YLeaf(YType.identityref, 'active-path'), [('ydk.models.openconfig.openconfig_transport_line_protection', 'APSPATHS')])),
                    ])
                    self.name = None
                    self.revertive = None
                    self.wait_to_restore_time = None
                    self.hold_off_time = None
                    self.primary_switch_threshold = None
                    self.primary_switch_hysteresis = None
                    self.secondary_switch_threshold = None
                    self.relative_switch_threshold = None
                    self.relative_switch_threshold_offset = None
                    self.force_to_port = None
                    self.active_path = None
                    self._segment_path = lambda: "state"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Aps.ApsModules.ApsModule.State, ['name', 'revertive', 'wait_to_restore_time', 'hold_off_time', 'primary_switch_threshold', 'primary_switch_hysteresis', 'secondary_switch_threshold', 'relative_switch_threshold', 'relative_switch_threshold_offset', 'force_to_port', 'active_path'], name, value)

                class ForceToPort(Enum):
                    """
                    ForceToPort (Enum Class)

                    .. data:: NONE = 0

                        Do not force the switch to stay on any line port

                    .. data:: PRIMARY = 1

                        Force the switch to stay on the primary line port

                    .. data:: SECONDARY = 2

                        Force the switch to stay on the secondary line port

                    """

                    NONE = Enum.YLeaf(0, "NONE")

                    PRIMARY = Enum.YLeaf(1, "PRIMARY")

                    SECONDARY = Enum.YLeaf(2, "SECONDARY")



            class Ports(_Entity_):
                """
                Top level grouping for automatic protection switch ports
                
                .. attribute:: line_primary_in
                
                    Container for information related to the line primary input port
                
                    **type**:  :py:class:`LinePrimaryIn<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LinePrimaryIn>`
                
                .. attribute:: line_primary_out
                
                    Container for information related to the line primary output port
                
                    **type**:  :py:class:`LinePrimaryOut<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LinePrimaryOut>`
                
                .. attribute:: line_secondary_in
                
                    Container for information related to the line secondary input port
                
                    **type**:  :py:class:`LineSecondaryIn<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LineSecondaryIn>`
                
                .. attribute:: line_secondary_out
                
                    Container for information related to the line secondary output port
                
                    **type**:  :py:class:`LineSecondaryOut<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LineSecondaryOut>`
                
                .. attribute:: common_in
                
                    Container for information related to the line common input port
                
                    **type**:  :py:class:`CommonIn<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.CommonIn>`
                
                .. attribute:: common_output
                
                    Container for information related to the line common output port
                
                    **type**:  :py:class:`CommonOutput<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.CommonOutput>`
                
                """
                _prefix = 'oc-line-protect'
                _revision = '2018-11-21'

                def __init__(self):
                    super().__init__()

                    self.yang_name = "ports"
                    self.yang_parent_name = "aps-module"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("line-primary-in", ("line_primary_in", Aps.ApsModules.ApsModule.Ports.LinePrimaryIn)), ("line-primary-out", ("line_primary_out", Aps.ApsModules.ApsModule.Ports.LinePrimaryOut)), ("line-secondary-in", ("line_secondary_in", Aps.ApsModules.ApsModule.Ports.LineSecondaryIn)), ("line-secondary-out", ("line_secondary_out", Aps.ApsModules.ApsModule.Ports.LineSecondaryOut)), ("common-in", ("common_in", Aps.ApsModules.ApsModule.Ports.CommonIn)), ("common-output", ("common_output", Aps.ApsModules.ApsModule.Ports.CommonOutput))])
                    self._leafs = OrderedDict()

                    self.line_primary_in = Aps.ApsModules.ApsModule.Ports.LinePrimaryIn()
                    self.line_primary_in.parent = self
                    self._children_name_map["line_primary_in"] = "line-primary-in"

                    self.line_primary_out = Aps.ApsModules.ApsModule.Ports.LinePrimaryOut()
                    self.line_primary_out.parent = self
                    self._children_name_map["line_primary_out"] = "line-primary-out"

                    self.line_secondary_in = Aps.ApsModules.ApsModule.Ports.LineSecondaryIn()
                    self.line_secondary_in.parent = self
                    self._children_name_map["line_secondary_in"] = "line-secondary-in"

                    self.line_secondary_out = Aps.ApsModules.ApsModule.Ports.LineSecondaryOut()
                    self.line_secondary_out.parent = self
                    self._children_name_map["line_secondary_out"] = "line-secondary-out"

                    self.common_in = Aps.ApsModules.ApsModule.Ports.CommonIn()
                    self.common_in.parent = self
                    self._children_name_map["common_in"] = "common-in"

                    self.common_output = Aps.ApsModules.ApsModule.Ports.CommonOutput()
                    self.common_output.parent = self
                    self._children_name_map["common_output"] = "common-output"
                    self._segment_path = lambda: "ports"
                    self._is_frozen = True

                def __setattr__(self, name, value):
                    self._perform_setattr(Aps.ApsModules.ApsModule.Ports, [], name, value)

                class LinePrimaryIn(_Entity_):
                    """
                    Container for information related to the line primary
                    input port
                    
                    .. attribute:: config
                    
                        Configuration data for the line primary input port
                    
                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.Config>`
                    
                    .. attribute:: state
                    
                        State data for the line primary input port
                    
                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.State>`
                    
                        **config**: False
                    
                    """
                    _prefix = 'oc-line-protect'
                    _revision = '2018-11-21'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "line-primary-in"
                        self.yang_parent_name = "ports"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("config", ("config", Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.Config)), ("state", ("state", Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.State))])
                        self._leafs = OrderedDict()

                        self.config = Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"

                        self.state = Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"
                        self._segment_path = lambda: "line-primary-in"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LinePrimaryIn, [], name, value)

                    class Config(_Entity_):
                        """
                        Configuration data for the line primary input port
                        
                        .. attribute:: enabled
                        
                            This leaf contains the configured, desired state of the port. Disabling the port turns off alarm reporting for the port
                        
                            **type**: bool
                        
                            **default value**: true
                        
                        .. attribute:: target_attenuation
                        
                            Target attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        
                            **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                                **range:** \-92233720368547758.08..92233720368547758.07
                        
                            **units**: dB
                        
                        """
                        _prefix = 'oc-line-protect'
                        _revision = '2018-11-21'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "line-primary-in"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                ('target_attenuation', (YLeaf(YType.str, 'target-attenuation'), ['Decimal64'])),
                            ])
                            self.enabled = None
                            self.target_attenuation = None
                            self._segment_path = lambda: "config"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.Config, ['enabled', 'target_attenuation'], name, value)


                    class State(_Entity_):
                        """
                        State data for the line primary input port
                        
                        .. attribute:: enabled
                        
                            This leaf contains the configured, desired state of the port. Disabling the port turns off alarm reporting for the port
                        
                            **type**: bool
                        
                            **config**: False
                        
                            **default value**: true
                        
                        .. attribute:: target_attenuation
                        
                            Target attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        
                            **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                                **range:** \-92233720368547758.08..92233720368547758.07
                        
                            **config**: False
                        
                            **units**: dB
                        
                        .. attribute:: attenuation
                        
                            The attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        
                            **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                                **range:** \-92233720368547758.08..92233720368547758.07
                        
                            **config**: False
                        
                            **units**: dB
                        
                        .. attribute:: optical_power
                        
                            The optical input power of this port in units of 0.01dBm. Optical input power represents the signal traversing from an external destination into the module. The power is measured before any attenuation. If avg/min/max statistics are not supported, the target is expected to just supply the instant value
                        
                            **type**:  :py:class:`OpticalPower<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.State.OpticalPower>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-line-protect'
                        _revision = '2018-11-21'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "line-primary-in"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("optical-power", ("optical_power", Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.State.OpticalPower))])
                            self._leafs = OrderedDict([
                                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                ('target_attenuation', (YLeaf(YType.str, 'target-attenuation'), ['Decimal64'])),
                                ('attenuation', (YLeaf(YType.str, 'attenuation'), ['Decimal64'])),
                            ])
                            self.enabled = None
                            self.target_attenuation = None
                            self.attenuation = None

                            self.optical_power = Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.State.OpticalPower()
                            self.optical_power.parent = self
                            self._children_name_map["optical_power"] = "optical-power"
                            self._segment_path = lambda: "state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.State, ['enabled', 'target_attenuation', 'attenuation'], name, value)

                        class OpticalPower(_Entity_):
                            """
                            The optical input power of this port in units of
                            0.01dBm. Optical input power represents the signal
                            traversing from an external destination into the module.
                            The power is measured before any attenuation. If avg/min/max
                            statistics are not supported, the target is expected to
                            just supply the instant value
                            
                            .. attribute:: instant
                            
                                The instantaneous value of the statistic
                            
                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                                    **range:** \-92233720368547758.08..92233720368547758.07
                            
                                **config**: False
                            
                                **units**: dBm
                            
                            .. attribute:: avg
                            
                                The arithmetic mean value of the statistic over the time interval
                            
                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                                    **range:** \-92233720368547758.08..92233720368547758.07
                            
                                **config**: False
                            
                                **units**: dBm
                            
                            .. attribute:: min
                            
                                The minimum value of the statistic over the time interval
                            
                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                                    **range:** \-92233720368547758.08..92233720368547758.07
                            
                                **config**: False
                            
                                **units**: dBm
                            
                            .. attribute:: max
                            
                                The maximum value of the statistic over the time interval
                            
                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                                    **range:** \-92233720368547758.08..92233720368547758.07
                            
                                **config**: False
                            
                                **units**: dBm
                            
                            .. attribute:: interval
                            
                                If supported by the system, this reports the time interval over which the min/max/average statistics are computed by the system
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                            .. attribute:: min_time
                            
                                The absolute time at which the minimum value occurred. The value is the timestamp in nanoseconds relative to  the Unix Epoch (Jan 1, 1970 00\:00\:00 UTC)
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                            .. attribute:: max_time
                            
                                The absolute time at which the maximum value occurred. The value is the timestamp in nanoseconds relative to  the Unix Epoch (Jan 1, 1970 00\:00\:00 UTC)
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-line-protect'
                            _revision = '2018-11-21'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "optical-power"
                                self.yang_parent_name = "state"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('instant', (YLeaf(YType.str, 'instant'), ['Decimal64'])),
                                    ('avg', (YLeaf(YType.str, 'avg'), ['Decimal64'])),
                                    ('min', (YLeaf(YType.str, 'min'), ['Decimal64'])),
                                    ('max', (YLeaf(YType.str, 'max'), ['Decimal64'])),
                                    ('interval', (YLeaf(YType.uint64, 'interval'), ['int'])),
                                    ('min_time', (YLeaf(YType.uint64, 'min-time'), ['int'])),
                                    ('max_time', (YLeaf(YType.uint64, 'max-time'), ['int'])),
                                ])
                                self.instant = None
                                self.avg = None
                                self.min = None
                                self.max = None
                                self.interval = None
                                self.min_time = None
                                self.max_time = None
                                self._segment_path = lambda: "optical-power"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LinePrimaryIn.State.OpticalPower, ['instant', 'avg', 'min', 'max', 'interval', 'min_time', 'max_time'], name, value)




                class LinePrimaryOut(_Entity_):
                    """
                    Container for information related to the line primary
                    output port
                    
                    .. attribute:: config
                    
                        Configuration data for the line primary output port
                    
                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.Config>`
                    
                    .. attribute:: state
                    
                        State data for the line primary output port
                    
                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.State>`
                    
                        **config**: False
                    
                    """
                    _prefix = 'oc-line-protect'
                    _revision = '2018-11-21'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "line-primary-out"
                        self.yang_parent_name = "ports"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("config", ("config", Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.Config)), ("state", ("state", Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.State))])
                        self._leafs = OrderedDict()

                        self.config = Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"

                        self.state = Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"
                        self._segment_path = lambda: "line-primary-out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LinePrimaryOut, [], name, value)

                    class Config(_Entity_):
                        """
                        Configuration data for the line primary output port
                        
                        .. attribute:: target_attenuation
                        
                            Target attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        
                            **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                                **range:** \-92233720368547758.08..92233720368547758.07
                        
                            **units**: dB
                        
                        """
                        _prefix = 'oc-line-protect'
                        _revision = '2018-11-21'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "line-primary-out"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('target_attenuation', (YLeaf(YType.str, 'target-attenuation'), ['Decimal64'])),
                            ])
                            self.target_attenuation = None
                            self._segment_path = lambda: "config"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.Config, ['target_attenuation'], name, value)


                    class State(_Entity_):
                        """
                        State data for the line primary output port
                        
                        .. attribute:: target_attenuation
                        
                            Target attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        
                            **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                                **range:** \-92233720368547758.08..92233720368547758.07
                        
                            **config**: False
                        
                            **units**: dB
                        
                        .. attribute:: attenuation
                        
                            The attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        
                            **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                                **range:** \-92233720368547758.08..92233720368547758.07
                        
                            **config**: False
                        
                            **units**: dB
                        
                        .. attribute:: optical_power
                        
                            The optical output power of this port in units of 0.01dBm. Optical output power represents the signal traversing from the module to an external destination. The power is measured after any attenuation. If avg/min/max statistics are not supported, the target is expected to just supply the instant value
                        
                            **type**:  :py:class:`OpticalPower<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.State.OpticalPower>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-line-protect'
                        _revision = '2018-11-21'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "line-primary-out"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("optical-power", ("optical_power", Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.State.OpticalPower))])
                            self._leafs = OrderedDict([
                                ('target_attenuation', (YLeaf(YType.str, 'target-attenuation'), ['Decimal64'])),
                                ('attenuation', (YLeaf(YType.str, 'attenuation'), ['Decimal64'])),
                            ])
                            self.target_attenuation = None
                            self.attenuation = None

                            self.optical_power = Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.State.OpticalPower()
                            self.optical_power.parent = self
                            self._children_name_map["optical_power"] = "optical-power"
                            self._segment_path = lambda: "state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.State, ['target_attenuation', 'attenuation'], name, value)

                        class OpticalPower(_Entity_):
                            """
                            The optical output power of this port in units of
                            0.01dBm. Optical output power represents the signal
                            traversing from the module to an external destination. The
                            power is measured after any attenuation. If avg/min/max
                            statistics are not supported, the target is expected to
                            just supply the instant value
                            
                            .. attribute:: instant
                            
                                The instantaneous value of the statistic
                            
                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                                    **range:** \-92233720368547758.08..92233720368547758.07
                            
                                **config**: False
                            
                                **units**: dBm
                            
                            .. attribute:: avg
                            
                                The arithmetic mean value of the statistic over the time interval
                            
                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                                    **range:** \-92233720368547758.08..92233720368547758.07
                            
                                **config**: False
                            
                                **units**: dBm
                            
                            .. attribute:: min
                            
                                The minimum value of the statistic over the time interval
                            
                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                                    **range:** \-92233720368547758.08..92233720368547758.07
                            
                                **config**: False
                            
                                **units**: dBm
                            
                            .. attribute:: max
                            
                                The maximum value of the statistic over the time interval
                            
                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                                    **range:** \-92233720368547758.08..92233720368547758.07
                            
                                **config**: False
                            
                                **units**: dBm
                            
                            .. attribute:: interval
                            
                                If supported by the system, this reports the time interval over which the min/max/average statistics are computed by the system
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                            .. attribute:: min_time
                            
                                The absolute time at which the minimum value occurred. The value is the timestamp in nanoseconds relative to  the Unix Epoch (Jan 1, 1970 00\:00\:00 UTC)
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                            .. attribute:: max_time
                            
                                The absolute time at which the maximum value occurred. The value is the timestamp in nanoseconds relative to  the Unix Epoch (Jan 1, 1970 00\:00\:00 UTC)
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-line-protect'
                            _revision = '2018-11-21'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "optical-power"
                                self.yang_parent_name = "state"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('instant', (YLeaf(YType.str, 'instant'), ['Decimal64'])),
                                    ('avg', (YLeaf(YType.str, 'avg'), ['Decimal64'])),
                                    ('min', (YLeaf(YType.str, 'min'), ['Decimal64'])),
                                    ('max', (YLeaf(YType.str, 'max'), ['Decimal64'])),
                                    ('interval', (YLeaf(YType.uint64, 'interval'), ['int'])),
                                    ('min_time', (YLeaf(YType.uint64, 'min-time'), ['int'])),
                                    ('max_time', (YLeaf(YType.uint64, 'max-time'), ['int'])),
                                ])
                                self.instant = None
                                self.avg = None
                                self.min = None
                                self.max = None
                                self.interval = None
                                self.min_time = None
                                self.max_time = None
                                self._segment_path = lambda: "optical-power"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LinePrimaryOut.State.OpticalPower, ['instant', 'avg', 'min', 'max', 'interval', 'min_time', 'max_time'], name, value)




                class LineSecondaryIn(_Entity_):
                    """
                    Container for information related to the line secondary
                    input port
                    
                    .. attribute:: config
                    
                        Configuration data for the line secondary input port
                    
                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.Config>`
                    
                    .. attribute:: state
                    
                        State data for the line secondary input port
                    
                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.State>`
                    
                        **config**: False
                    
                    """
                    _prefix = 'oc-line-protect'
                    _revision = '2018-11-21'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "line-secondary-in"
                        self.yang_parent_name = "ports"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("config", ("config", Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.Config)), ("state", ("state", Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.State))])
                        self._leafs = OrderedDict()

                        self.config = Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"

                        self.state = Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"
                        self._segment_path = lambda: "line-secondary-in"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LineSecondaryIn, [], name, value)

                    class Config(_Entity_):
                        """
                        Configuration data for the line secondary input port
                        
                        .. attribute:: enabled
                        
                            This leaf contains the configured, desired state of the port. Disabling the port turns off alarm reporting for the port
                        
                            **type**: bool
                        
                            **default value**: true
                        
                        .. attribute:: target_attenuation
                        
                            Target attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        
                            **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                                **range:** \-92233720368547758.08..92233720368547758.07
                        
                            **units**: dB
                        
                        """
                        _prefix = 'oc-line-protect'
                        _revision = '2018-11-21'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "line-secondary-in"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                ('target_attenuation', (YLeaf(YType.str, 'target-attenuation'), ['Decimal64'])),
                            ])
                            self.enabled = None
                            self.target_attenuation = None
                            self._segment_path = lambda: "config"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.Config, ['enabled', 'target_attenuation'], name, value)


                    class State(_Entity_):
                        """
                        State data for the line secondary input port
                        
                        .. attribute:: enabled
                        
                            This leaf contains the configured, desired state of the port. Disabling the port turns off alarm reporting for the port
                        
                            **type**: bool
                        
                            **config**: False
                        
                            **default value**: true
                        
                        .. attribute:: target_attenuation
                        
                            Target attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        
                            **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                                **range:** \-92233720368547758.08..92233720368547758.07
                        
                            **config**: False
                        
                            **units**: dB
                        
                        .. attribute:: attenuation
                        
                            The attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        
                            **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                                **range:** \-92233720368547758.08..92233720368547758.07
                        
                            **config**: False
                        
                            **units**: dB
                        
                        .. attribute:: optical_power
                        
                            The optical input power of this port in units of 0.01dBm. Optical input power represents the signal traversing from an external destination into the module. The power is measured before any attenuation. If avg/min/max statistics are not supported, the target is expected to just supply the instant value
                        
                            **type**:  :py:class:`OpticalPower<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.State.OpticalPower>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-line-protect'
                        _revision = '2018-11-21'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "line-secondary-in"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("optical-power", ("optical_power", Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.State.OpticalPower))])
                            self._leafs = OrderedDict([
                                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                ('target_attenuation', (YLeaf(YType.str, 'target-attenuation'), ['Decimal64'])),
                                ('attenuation', (YLeaf(YType.str, 'attenuation'), ['Decimal64'])),
                            ])
                            self.enabled = None
                            self.target_attenuation = None
                            self.attenuation = None

                            self.optical_power = Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.State.OpticalPower()
                            self.optical_power.parent = self
                            self._children_name_map["optical_power"] = "optical-power"
                            self._segment_path = lambda: "state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.State, ['enabled', 'target_attenuation', 'attenuation'], name, value)

                        class OpticalPower(_Entity_):
                            """
                            The optical input power of this port in units of
                            0.01dBm. Optical input power represents the signal
                            traversing from an external destination into the module.
                            The power is measured before any attenuation. If avg/min/max
                            statistics are not supported, the target is expected to
                            just supply the instant value
                            
                            .. attribute:: instant
                            
                                The instantaneous value of the statistic
                            
                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                                    **range:** \-92233720368547758.08..92233720368547758.07
                            
                                **config**: False
                            
                                **units**: dBm
                            
                            .. attribute:: avg
                            
                                The arithmetic mean value of the statistic over the time interval
                            
                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                                    **range:** \-92233720368547758.08..92233720368547758.07
                            
                                **config**: False
                            
                                **units**: dBm
                            
                            .. attribute:: min
                            
                                The minimum value of the statistic over the time interval
                            
                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                                    **range:** \-92233720368547758.08..92233720368547758.07
                            
                                **config**: False
                            
                                **units**: dBm
                            
                            .. attribute:: max
                            
                                The maximum value of the statistic over the time interval
                            
                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                                    **range:** \-92233720368547758.08..92233720368547758.07
                            
                                **config**: False
                            
                                **units**: dBm
                            
                            .. attribute:: interval
                            
                                If supported by the system, this reports the time interval over which the min/max/average statistics are computed by the system
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                            .. attribute:: min_time
                            
                                The absolute time at which the minimum value occurred. The value is the timestamp in nanoseconds relative to  the Unix Epoch (Jan 1, 1970 00\:00\:00 UTC)
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                            .. attribute:: max_time
                            
                                The absolute time at which the maximum value occurred. The value is the timestamp in nanoseconds relative to  the Unix Epoch (Jan 1, 1970 00\:00\:00 UTC)
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-line-protect'
                            _revision = '2018-11-21'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "optical-power"
                                self.yang_parent_name = "state"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('instant', (YLeaf(YType.str, 'instant'), ['Decimal64'])),
                                    ('avg', (YLeaf(YType.str, 'avg'), ['Decimal64'])),
                                    ('min', (YLeaf(YType.str, 'min'), ['Decimal64'])),
                                    ('max', (YLeaf(YType.str, 'max'), ['Decimal64'])),
                                    ('interval', (YLeaf(YType.uint64, 'interval'), ['int'])),
                                    ('min_time', (YLeaf(YType.uint64, 'min-time'), ['int'])),
                                    ('max_time', (YLeaf(YType.uint64, 'max-time'), ['int'])),
                                ])
                                self.instant = None
                                self.avg = None
                                self.min = None
                                self.max = None
                                self.interval = None
                                self.min_time = None
                                self.max_time = None
                                self._segment_path = lambda: "optical-power"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LineSecondaryIn.State.OpticalPower, ['instant', 'avg', 'min', 'max', 'interval', 'min_time', 'max_time'], name, value)




                class LineSecondaryOut(_Entity_):
                    """
                    Container for information related to the line secondary
                    output port
                    
                    .. attribute:: config
                    
                        Configuration data for the line secondary output port
                    
                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.Config>`
                    
                    .. attribute:: state
                    
                        State data for the line secondary output port
                    
                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.State>`
                    
                        **config**: False
                    
                    """
                    _prefix = 'oc-line-protect'
                    _revision = '2018-11-21'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "line-secondary-out"
                        self.yang_parent_name = "ports"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("config", ("config", Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.Config)), ("state", ("state", Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.State))])
                        self._leafs = OrderedDict()

                        self.config = Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"

                        self.state = Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"
                        self._segment_path = lambda: "line-secondary-out"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LineSecondaryOut, [], name, value)

                    class Config(_Entity_):
                        """
                        Configuration data for the line secondary output port
                        
                        .. attribute:: target_attenuation
                        
                            Target attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        
                            **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                                **range:** \-92233720368547758.08..92233720368547758.07
                        
                            **units**: dB
                        
                        """
                        _prefix = 'oc-line-protect'
                        _revision = '2018-11-21'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "line-secondary-out"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('target_attenuation', (YLeaf(YType.str, 'target-attenuation'), ['Decimal64'])),
                            ])
                            self.target_attenuation = None
                            self._segment_path = lambda: "config"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.Config, ['target_attenuation'], name, value)


                    class State(_Entity_):
                        """
                        State data for the line secondary output port
                        
                        .. attribute:: target_attenuation
                        
                            Target attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        
                            **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                                **range:** \-92233720368547758.08..92233720368547758.07
                        
                            **config**: False
                        
                            **units**: dB
                        
                        .. attribute:: attenuation
                        
                            The attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        
                            **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                                **range:** \-92233720368547758.08..92233720368547758.07
                        
                            **config**: False
                        
                            **units**: dB
                        
                        .. attribute:: optical_power
                        
                            The optical output power of this port in units of 0.01dBm. Optical output power represents the signal traversing from the module to an external destination. The power is measured after any attenuation. If avg/min/max statistics are not supported, the target is expected to just supply the instant value
                        
                            **type**:  :py:class:`OpticalPower<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.State.OpticalPower>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-line-protect'
                        _revision = '2018-11-21'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "line-secondary-out"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("optical-power", ("optical_power", Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.State.OpticalPower))])
                            self._leafs = OrderedDict([
                                ('target_attenuation', (YLeaf(YType.str, 'target-attenuation'), ['Decimal64'])),
                                ('attenuation', (YLeaf(YType.str, 'attenuation'), ['Decimal64'])),
                            ])
                            self.target_attenuation = None
                            self.attenuation = None

                            self.optical_power = Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.State.OpticalPower()
                            self.optical_power.parent = self
                            self._children_name_map["optical_power"] = "optical-power"
                            self._segment_path = lambda: "state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.State, ['target_attenuation', 'attenuation'], name, value)

                        class OpticalPower(_Entity_):
                            """
                            The optical output power of this port in units of
                            0.01dBm. Optical output power represents the signal
                            traversing from the module to an external destination. The
                            power is measured after any attenuation. If avg/min/max
                            statistics are not supported, the target is expected to
                            just supply the instant value
                            
                            .. attribute:: instant
                            
                                The instantaneous value of the statistic
                            
                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                                    **range:** \-92233720368547758.08..92233720368547758.07
                            
                                **config**: False
                            
                                **units**: dBm
                            
                            .. attribute:: avg
                            
                                The arithmetic mean value of the statistic over the time interval
                            
                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                                    **range:** \-92233720368547758.08..92233720368547758.07
                            
                                **config**: False
                            
                                **units**: dBm
                            
                            .. attribute:: min
                            
                                The minimum value of the statistic over the time interval
                            
                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                                    **range:** \-92233720368547758.08..92233720368547758.07
                            
                                **config**: False
                            
                                **units**: dBm
                            
                            .. attribute:: max
                            
                                The maximum value of the statistic over the time interval
                            
                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                                    **range:** \-92233720368547758.08..92233720368547758.07
                            
                                **config**: False
                            
                                **units**: dBm
                            
                            .. attribute:: interval
                            
                                If supported by the system, this reports the time interval over which the min/max/average statistics are computed by the system
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                            .. attribute:: min_time
                            
                                The absolute time at which the minimum value occurred. The value is the timestamp in nanoseconds relative to  the Unix Epoch (Jan 1, 1970 00\:00\:00 UTC)
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                            .. attribute:: max_time
                            
                                The absolute time at which the maximum value occurred. The value is the timestamp in nanoseconds relative to  the Unix Epoch (Jan 1, 1970 00\:00\:00 UTC)
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-line-protect'
                            _revision = '2018-11-21'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "optical-power"
                                self.yang_parent_name = "state"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('instant', (YLeaf(YType.str, 'instant'), ['Decimal64'])),
                                    ('avg', (YLeaf(YType.str, 'avg'), ['Decimal64'])),
                                    ('min', (YLeaf(YType.str, 'min'), ['Decimal64'])),
                                    ('max', (YLeaf(YType.str, 'max'), ['Decimal64'])),
                                    ('interval', (YLeaf(YType.uint64, 'interval'), ['int'])),
                                    ('min_time', (YLeaf(YType.uint64, 'min-time'), ['int'])),
                                    ('max_time', (YLeaf(YType.uint64, 'max-time'), ['int'])),
                                ])
                                self.instant = None
                                self.avg = None
                                self.min = None
                                self.max = None
                                self.interval = None
                                self.min_time = None
                                self.max_time = None
                                self._segment_path = lambda: "optical-power"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Aps.ApsModules.ApsModule.Ports.LineSecondaryOut.State.OpticalPower, ['instant', 'avg', 'min', 'max', 'interval', 'min_time', 'max_time'], name, value)




                class CommonIn(_Entity_):
                    """
                    Container for information related to the line common
                    input port
                    
                    .. attribute:: config
                    
                        Configuration data for the line common input port
                    
                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.CommonIn.Config>`
                    
                    .. attribute:: state
                    
                        State data for the line common input port
                    
                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.CommonIn.State>`
                    
                        **config**: False
                    
                    """
                    _prefix = 'oc-line-protect'
                    _revision = '2018-11-21'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "common-in"
                        self.yang_parent_name = "ports"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("config", ("config", Aps.ApsModules.ApsModule.Ports.CommonIn.Config)), ("state", ("state", Aps.ApsModules.ApsModule.Ports.CommonIn.State))])
                        self._leafs = OrderedDict()

                        self.config = Aps.ApsModules.ApsModule.Ports.CommonIn.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"

                        self.state = Aps.ApsModules.ApsModule.Ports.CommonIn.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"
                        self._segment_path = lambda: "common-in"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Aps.ApsModules.ApsModule.Ports.CommonIn, [], name, value)

                    class Config(_Entity_):
                        """
                        Configuration data for the line common input port
                        
                        .. attribute:: enabled
                        
                            This leaf contains the configured, desired state of the port. Disabling the port turns off alarm reporting for the port
                        
                            **type**: bool
                        
                            **default value**: true
                        
                        .. attribute:: target_attenuation
                        
                            Target attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        
                            **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                                **range:** \-92233720368547758.08..92233720368547758.07
                        
                            **units**: dB
                        
                        """
                        _prefix = 'oc-line-protect'
                        _revision = '2018-11-21'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "common-in"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                ('target_attenuation', (YLeaf(YType.str, 'target-attenuation'), ['Decimal64'])),
                            ])
                            self.enabled = None
                            self.target_attenuation = None
                            self._segment_path = lambda: "config"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Aps.ApsModules.ApsModule.Ports.CommonIn.Config, ['enabled', 'target_attenuation'], name, value)


                    class State(_Entity_):
                        """
                        State data for the line common input port
                        
                        .. attribute:: enabled
                        
                            This leaf contains the configured, desired state of the port. Disabling the port turns off alarm reporting for the port
                        
                            **type**: bool
                        
                            **config**: False
                        
                            **default value**: true
                        
                        .. attribute:: target_attenuation
                        
                            Target attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        
                            **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                                **range:** \-92233720368547758.08..92233720368547758.07
                        
                            **config**: False
                        
                            **units**: dB
                        
                        .. attribute:: attenuation
                        
                            The attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        
                            **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                                **range:** \-92233720368547758.08..92233720368547758.07
                        
                            **config**: False
                        
                            **units**: dB
                        
                        .. attribute:: optical_power
                        
                            The optical input power of this port in units of 0.01dBm. Optical input power represents the signal traversing from an external destination into the module. The power is measured before any attenuation. If avg/min/max statistics are not supported, the target is expected to just supply the instant value
                        
                            **type**:  :py:class:`OpticalPower<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.CommonIn.State.OpticalPower>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-line-protect'
                        _revision = '2018-11-21'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "common-in"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("optical-power", ("optical_power", Aps.ApsModules.ApsModule.Ports.CommonIn.State.OpticalPower))])
                            self._leafs = OrderedDict([
                                ('enabled', (YLeaf(YType.boolean, 'enabled'), ['bool'])),
                                ('target_attenuation', (YLeaf(YType.str, 'target-attenuation'), ['Decimal64'])),
                                ('attenuation', (YLeaf(YType.str, 'attenuation'), ['Decimal64'])),
                            ])
                            self.enabled = None
                            self.target_attenuation = None
                            self.attenuation = None

                            self.optical_power = Aps.ApsModules.ApsModule.Ports.CommonIn.State.OpticalPower()
                            self.optical_power.parent = self
                            self._children_name_map["optical_power"] = "optical-power"
                            self._segment_path = lambda: "state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Aps.ApsModules.ApsModule.Ports.CommonIn.State, ['enabled', 'target_attenuation', 'attenuation'], name, value)

                        class OpticalPower(_Entity_):
                            """
                            The optical input power of this port in units of
                            0.01dBm. Optical input power represents the signal
                            traversing from an external destination into the module.
                            The power is measured before any attenuation. If avg/min/max
                            statistics are not supported, the target is expected to
                            just supply the instant value
                            
                            .. attribute:: instant
                            
                                The instantaneous value of the statistic
                            
                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                                    **range:** \-92233720368547758.08..92233720368547758.07
                            
                                **config**: False
                            
                                **units**: dBm
                            
                            .. attribute:: avg
                            
                                The arithmetic mean value of the statistic over the time interval
                            
                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                                    **range:** \-92233720368547758.08..92233720368547758.07
                            
                                **config**: False
                            
                                **units**: dBm
                            
                            .. attribute:: min
                            
                                The minimum value of the statistic over the time interval
                            
                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                                    **range:** \-92233720368547758.08..92233720368547758.07
                            
                                **config**: False
                            
                                **units**: dBm
                            
                            .. attribute:: max
                            
                                The maximum value of the statistic over the time interval
                            
                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                                    **range:** \-92233720368547758.08..92233720368547758.07
                            
                                **config**: False
                            
                                **units**: dBm
                            
                            .. attribute:: interval
                            
                                If supported by the system, this reports the time interval over which the min/max/average statistics are computed by the system
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                            .. attribute:: min_time
                            
                                The absolute time at which the minimum value occurred. The value is the timestamp in nanoseconds relative to  the Unix Epoch (Jan 1, 1970 00\:00\:00 UTC)
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                            .. attribute:: max_time
                            
                                The absolute time at which the maximum value occurred. The value is the timestamp in nanoseconds relative to  the Unix Epoch (Jan 1, 1970 00\:00\:00 UTC)
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-line-protect'
                            _revision = '2018-11-21'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "optical-power"
                                self.yang_parent_name = "state"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('instant', (YLeaf(YType.str, 'instant'), ['Decimal64'])),
                                    ('avg', (YLeaf(YType.str, 'avg'), ['Decimal64'])),
                                    ('min', (YLeaf(YType.str, 'min'), ['Decimal64'])),
                                    ('max', (YLeaf(YType.str, 'max'), ['Decimal64'])),
                                    ('interval', (YLeaf(YType.uint64, 'interval'), ['int'])),
                                    ('min_time', (YLeaf(YType.uint64, 'min-time'), ['int'])),
                                    ('max_time', (YLeaf(YType.uint64, 'max-time'), ['int'])),
                                ])
                                self.instant = None
                                self.avg = None
                                self.min = None
                                self.max = None
                                self.interval = None
                                self.min_time = None
                                self.max_time = None
                                self._segment_path = lambda: "optical-power"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Aps.ApsModules.ApsModule.Ports.CommonIn.State.OpticalPower, ['instant', 'avg', 'min', 'max', 'interval', 'min_time', 'max_time'], name, value)




                class CommonOutput(_Entity_):
                    """
                    Container for information related to the line common
                    output port
                    
                    .. attribute:: config
                    
                        Configuration data for the line common output port
                    
                        **type**:  :py:class:`Config<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.CommonOutput.Config>`
                    
                    .. attribute:: state
                    
                        State data for the line common output port
                    
                        **type**:  :py:class:`State<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.CommonOutput.State>`
                    
                        **config**: False
                    
                    """
                    _prefix = 'oc-line-protect'
                    _revision = '2018-11-21'

                    def __init__(self):
                        super().__init__()

                        self.yang_name = "common-output"
                        self.yang_parent_name = "ports"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("config", ("config", Aps.ApsModules.ApsModule.Ports.CommonOutput.Config)), ("state", ("state", Aps.ApsModules.ApsModule.Ports.CommonOutput.State))])
                        self._leafs = OrderedDict()

                        self.config = Aps.ApsModules.ApsModule.Ports.CommonOutput.Config()
                        self.config.parent = self
                        self._children_name_map["config"] = "config"

                        self.state = Aps.ApsModules.ApsModule.Ports.CommonOutput.State()
                        self.state.parent = self
                        self._children_name_map["state"] = "state"
                        self._segment_path = lambda: "common-output"
                        self._is_frozen = True

                    def __setattr__(self, name, value):
                        self._perform_setattr(Aps.ApsModules.ApsModule.Ports.CommonOutput, [], name, value)

                    class Config(_Entity_):
                        """
                        Configuration data for the line common output port
                        
                        .. attribute:: target_attenuation
                        
                            Target attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        
                            **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                                **range:** \-92233720368547758.08..92233720368547758.07
                        
                            **units**: dB
                        
                        """
                        _prefix = 'oc-line-protect'
                        _revision = '2018-11-21'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "config"
                            self.yang_parent_name = "common-output"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('target_attenuation', (YLeaf(YType.str, 'target-attenuation'), ['Decimal64'])),
                            ])
                            self.target_attenuation = None
                            self._segment_path = lambda: "config"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Aps.ApsModules.ApsModule.Ports.CommonOutput.Config, ['target_attenuation'], name, value)


                    class State(_Entity_):
                        """
                        State data for the line common output port
                        
                        .. attribute:: target_attenuation
                        
                            Target attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        
                            **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                                **range:** \-92233720368547758.08..92233720368547758.07
                        
                            **config**: False
                        
                            **units**: dB
                        
                        .. attribute:: attenuation
                        
                            The attenuation of the variable optical attenuator associated with the port in increments of 0.01 dB
                        
                            **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                        
                                **range:** \-92233720368547758.08..92233720368547758.07
                        
                            **config**: False
                        
                            **units**: dB
                        
                        .. attribute:: optical_power
                        
                            The optical output power of this port in units of 0.01dBm. Optical output power represents the signal traversing from the module to an external destination. The power is measured after any attenuation. If avg/min/max statistics are not supported, the target is expected to just supply the instant value
                        
                            **type**:  :py:class:`OpticalPower<ydk.models.openconfig.openconfig_transport_line_protection.Aps.ApsModules.ApsModule.Ports.CommonOutput.State.OpticalPower>`
                        
                            **config**: False
                        
                        """
                        _prefix = 'oc-line-protect'
                        _revision = '2018-11-21'

                        def __init__(self):
                            super().__init__()

                            self.yang_name = "state"
                            self.yang_parent_name = "common-output"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("optical-power", ("optical_power", Aps.ApsModules.ApsModule.Ports.CommonOutput.State.OpticalPower))])
                            self._leafs = OrderedDict([
                                ('target_attenuation', (YLeaf(YType.str, 'target-attenuation'), ['Decimal64'])),
                                ('attenuation', (YLeaf(YType.str, 'attenuation'), ['Decimal64'])),
                            ])
                            self.target_attenuation = None
                            self.attenuation = None

                            self.optical_power = Aps.ApsModules.ApsModule.Ports.CommonOutput.State.OpticalPower()
                            self.optical_power.parent = self
                            self._children_name_map["optical_power"] = "optical-power"
                            self._segment_path = lambda: "state"
                            self._is_frozen = True

                        def __setattr__(self, name, value):
                            self._perform_setattr(Aps.ApsModules.ApsModule.Ports.CommonOutput.State, ['target_attenuation', 'attenuation'], name, value)

                        class OpticalPower(_Entity_):
                            """
                            The optical output power of this port in units of
                            0.01dBm. Optical output power represents the signal
                            traversing from the module to an external destination. The
                            power is measured after any attenuation. If avg/min/max
                            statistics are not supported, the target is expected to
                            just supply the instant value
                            
                            .. attribute:: instant
                            
                                The instantaneous value of the statistic
                            
                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                                    **range:** \-92233720368547758.08..92233720368547758.07
                            
                                **config**: False
                            
                                **units**: dBm
                            
                            .. attribute:: avg
                            
                                The arithmetic mean value of the statistic over the time interval
                            
                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                                    **range:** \-92233720368547758.08..92233720368547758.07
                            
                                **config**: False
                            
                                **units**: dBm
                            
                            .. attribute:: min
                            
                                The minimum value of the statistic over the time interval
                            
                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                                    **range:** \-92233720368547758.08..92233720368547758.07
                            
                                **config**: False
                            
                                **units**: dBm
                            
                            .. attribute:: max
                            
                                The maximum value of the statistic over the time interval
                            
                                **type**: :py:class:`Decimal64<ydk.types.Decimal64>`
                            
                                    **range:** \-92233720368547758.08..92233720368547758.07
                            
                                **config**: False
                            
                                **units**: dBm
                            
                            .. attribute:: interval
                            
                                If supported by the system, this reports the time interval over which the min/max/average statistics are computed by the system
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                            .. attribute:: min_time
                            
                                The absolute time at which the minimum value occurred. The value is the timestamp in nanoseconds relative to  the Unix Epoch (Jan 1, 1970 00\:00\:00 UTC)
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                            .. attribute:: max_time
                            
                                The absolute time at which the maximum value occurred. The value is the timestamp in nanoseconds relative to  the Unix Epoch (Jan 1, 1970 00\:00\:00 UTC)
                            
                                **type**: int
                            
                                    **range:** 0..18446744073709551615
                            
                                **config**: False
                            
                            """
                            _prefix = 'oc-line-protect'
                            _revision = '2018-11-21'

                            def __init__(self):
                                super().__init__()

                                self.yang_name = "optical-power"
                                self.yang_parent_name = "state"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('instant', (YLeaf(YType.str, 'instant'), ['Decimal64'])),
                                    ('avg', (YLeaf(YType.str, 'avg'), ['Decimal64'])),
                                    ('min', (YLeaf(YType.str, 'min'), ['Decimal64'])),
                                    ('max', (YLeaf(YType.str, 'max'), ['Decimal64'])),
                                    ('interval', (YLeaf(YType.uint64, 'interval'), ['int'])),
                                    ('min_time', (YLeaf(YType.uint64, 'min-time'), ['int'])),
                                    ('max_time', (YLeaf(YType.uint64, 'max-time'), ['int'])),
                                ])
                                self.instant = None
                                self.avg = None
                                self.min = None
                                self.max = None
                                self.interval = None
                                self.min_time = None
                                self.max_time = None
                                self._segment_path = lambda: "optical-power"
                                self._is_frozen = True

                            def __setattr__(self, name, value):
                                self._perform_setattr(Aps.ApsModules.ApsModule.Ports.CommonOutput.State.OpticalPower, ['instant', 'avg', 'min', 'max', 'interval', 'min_time', 'max_time'], name, value)







    def clone_ptr(self):
        self._top_entity = Aps()
        return self._top_entity


class PRIMARY(APSPATHS):
    """
    The primary line path connected to an automatic protection
    switch port indicating the primary/preferred path
    
    """
    _prefix = 'oc-line-protect'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/optical-transport-line-protection", pref="openconfig-transport-line-protection", tag="openconfig-transport-line-protection:PRIMARY"):
        super().__init__(ns, pref, tag)


class SECONDARY(APSPATHS):
    """
    The secondary line path connected to an automatic protection
    switch port indicating the secondary path
    
    """
    _prefix = 'oc-line-protect'
    _revision = '2018-11-21'

    def __init__(self, ns="http://openconfig.net/yang/optical-transport-line-protection", pref="openconfig-transport-line-protection", tag="openconfig-transport-line-protection:SECONDARY"):
        super().__init__(ns, pref, tag)






""" openconfig_alarm_types 

This module defines operational state data related to alarms
that the device is reporting.

This model reuses some data items defined in the draft IETF
YANG Alarm Module\:
https\://tools.ietf.org/html/draft\-vallin\-netmod\-alarm\-module\-02

Portions of this code were derived from the draft IETF YANG Alarm
Module. Please reproduce this note if possible.

IETF code is subject to the following copyright and license\:
Copyright (c) IETF Trust and the persons identified as authors of
the code.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, is permitted pursuant to, and subject to the license
terms contained in, the Simplified BSD License set forth in
Section 4.c of the IETF Trust's Legal Provisions Relating
to IETF Documents (http\://trustee.ietf.org/license\-info).

"""
from collections import OrderedDict

from ydk.types import Entity as _Entity_
from ydk.types import EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class OPENCONFIGALARMTYPEID(Identity):
    """
    Base identity for alarm type ID profiles
    
    """
    _prefix = 'oc-alarm-types'
    _revision = '2018-01-16'

    def __init__(self, ns="http://openconfig.net/yang/alarms/types", pref="openconfig-alarm-types", tag="openconfig-alarm-types:OPENCONFIG_ALARM_TYPE_ID"):
        super().__init__(ns, pref, tag)


class OPENCONFIGALARMSEVERITY(Identity):
    """
    Base identity for alarm severity profiles. Derived
    identities are based on contents of the draft
    IETF YANG Alarm Module
    
    """
    _prefix = 'oc-alarm-types'
    _revision = '2018-01-16'

    def __init__(self, ns="http://openconfig.net/yang/alarms/types", pref="openconfig-alarm-types", tag="openconfig-alarm-types:OPENCONFIG_ALARM_SEVERITY"):
        super().__init__(ns, pref, tag)


class AIS(OPENCONFIGALARMTYPEID):
    """
    Defines an alarm indication signal type of alarm
    
    """
    _prefix = 'oc-alarm-types'
    _revision = '2018-01-16'

    def __init__(self, ns="http://openconfig.net/yang/alarms/types", pref="openconfig-alarm-types", tag="openconfig-alarm-types:AIS"):
        super().__init__(ns, pref, tag)


class EQPT(OPENCONFIGALARMTYPEID):
    """
    Defines an equipment related type of alarm that is specific
    to the physical hardware
    
    """
    _prefix = 'oc-alarm-types'
    _revision = '2018-01-16'

    def __init__(self, ns="http://openconfig.net/yang/alarms/types", pref="openconfig-alarm-types", tag="openconfig-alarm-types:EQPT"):
        super().__init__(ns, pref, tag)


class LOS(OPENCONFIGALARMTYPEID):
    """
    Defines a loss of signal type of alarm
    
    """
    _prefix = 'oc-alarm-types'
    _revision = '2018-01-16'

    def __init__(self, ns="http://openconfig.net/yang/alarms/types", pref="openconfig-alarm-types", tag="openconfig-alarm-types:LOS"):
        super().__init__(ns, pref, tag)


class OTS(OPENCONFIGALARMTYPEID):
    """
    Defines a optical transport signal type of alarm
    
    """
    _prefix = 'oc-alarm-types'
    _revision = '2018-01-16'

    def __init__(self, ns="http://openconfig.net/yang/alarms/types", pref="openconfig-alarm-types", tag="openconfig-alarm-types:OTS"):
        super().__init__(ns, pref, tag)


class UNKNOWN(OPENCONFIGALARMSEVERITY):
    """
    Indicates that the severity level could not be determined.
    This level SHOULD be avoided.
    
    """
    _prefix = 'oc-alarm-types'
    _revision = '2018-01-16'

    def __init__(self, ns="http://openconfig.net/yang/alarms/types", pref="openconfig-alarm-types", tag="openconfig-alarm-types:UNKNOWN"):
        super().__init__(ns, pref, tag)


class MINOR(OPENCONFIGALARMSEVERITY):
    """
    Indicates the existence of a non\-service affecting fault
    condition and that corrective action should be taken in
    order to prevent a more serious (for example, service
    affecting) fault. Such a severity can be reported, for
    example, when the detected alarm condition is not currently
    degrading the capacity of the resource
    
    """
    _prefix = 'oc-alarm-types'
    _revision = '2018-01-16'

    def __init__(self, ns="http://openconfig.net/yang/alarms/types", pref="openconfig-alarm-types", tag="openconfig-alarm-types:MINOR"):
        super().__init__(ns, pref, tag)


class WARNING(OPENCONFIGALARMSEVERITY):
    """
    Indicates the detection of a potential or impending service
    affecting fault, before any significant effects have been felt.
    Action should be taken to further diagnose (if necessary) and
    correct the problem in order to prevent it from becoming a more
    serious service affecting fault.
    
    """
    _prefix = 'oc-alarm-types'
    _revision = '2018-01-16'

    def __init__(self, ns="http://openconfig.net/yang/alarms/types", pref="openconfig-alarm-types", tag="openconfig-alarm-types:WARNING"):
        super().__init__(ns, pref, tag)


class MAJOR(OPENCONFIGALARMSEVERITY):
    """
    Indicates that a service affecting condition has developed
    and an urgent corrective action is required. Such a severity
    can be reported, for example, when there is a severe
    degradation in the capability of the resource and its full
    capability must be restored.
    
    """
    _prefix = 'oc-alarm-types'
    _revision = '2018-01-16'

    def __init__(self, ns="http://openconfig.net/yang/alarms/types", pref="openconfig-alarm-types", tag="openconfig-alarm-types:MAJOR"):
        super().__init__(ns, pref, tag)


class CRITICAL(OPENCONFIGALARMSEVERITY):
    """
    Indicates that a service affecting condition has occurred
    and an immediate corrective action is required. Such a
    severity can be reported, for example, when a resource becomes
    totally out of service and its capability must be restored.
    
    """
    _prefix = 'oc-alarm-types'
    _revision = '2018-01-16'

    def __init__(self, ns="http://openconfig.net/yang/alarms/types", pref="openconfig-alarm-types", tag="openconfig-alarm-types:CRITICAL"):
        super().__init__(ns, pref, tag)






""" openconfig_transport_types 

This module contains general type definitions and identities
for optical transport models.

"""
from collections import OrderedDict

from ydk.types import Entity as _Entity_
from ydk.types import EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error

from ydk.models.openconfig.openconfig_platform_types import OPENCONFIGHARDWARECOMPONENT


class AdminStateType(Enum):
    """
    AdminStateType (Enum Class)

    Administrative state modes for

    logical channels in the transponder model.

    .. data:: ENABLED = 0

        Sets the channel admin state to enabled

    .. data:: DISABLED = 1

        Sets the channel admin state to disabled

    .. data:: MAINT = 2

        Sets the channel to maintenance / diagnostic mode

    """

    ENABLED = Enum.YLeaf(0, "ENABLED")

    DISABLED = Enum.YLeaf(1, "DISABLED")

    MAINT = Enum.YLeaf(2, "MAINT")


class LoopbackModeType(Enum):
    """
    LoopbackModeType (Enum Class)

    Loopback modes for transponder logical channels

    .. data:: NONE = 0

        No loopback is applied

    .. data:: FACILITY = 1

        A loopback which directs traffic normally transmitted

        on the port back to the device as if received on the same

        port from an external source.

    .. data:: TERMINAL = 2

        A loopback which directs traffic received from an external

        source on the port back out the transmit side of the same

        port.

    """

    NONE = Enum.YLeaf(0, "NONE")

    FACILITY = Enum.YLeaf(1, "FACILITY")

    TERMINAL = Enum.YLeaf(2, "TERMINAL")


class FRAMEMAPPINGPROTOCOL(Identity):
    """
    Base identity for frame mapping protocols that can be used
    when mapping Ethernet, OTN or other client signals to OTN
    logical channels.
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:FRAME_MAPPING_PROTOCOL"):
        super().__init__(ns, pref, tag)


class TRIBUTARYSLOTGRANULARITY(Identity):
    """
    Base identity for tributary slot granularity for OTN
    logical channels.
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TRIBUTARY_SLOT_GRANULARITY"):
        super().__init__(ns, pref, tag)


class TRIBUTARYPROTOCOLTYPE(Identity):
    """
    Base identity for protocol framing used by tributary
    signals.
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TRIBUTARY_PROTOCOL_TYPE"):
        super().__init__(ns, pref, tag)


class TRANSCEIVERFORMFACTORTYPE(Identity):
    """
    Base identity for identifying the type of pluggable optic
    transceiver (i.e,. form factor) used in a port.
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TRANSCEIVER_FORM_FACTOR_TYPE"):
        super().__init__(ns, pref, tag)


class FIBERCONNECTORTYPE(Identity):
    """
    Type of optical fiber connector
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:FIBER_CONNECTOR_TYPE"):
        super().__init__(ns, pref, tag)


class ETHERNETPMDTYPE(Identity):
    """
    Ethernet compliance codes (PMD) supported by transceivers
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:ETHERNET_PMD_TYPE"):
        super().__init__(ns, pref, tag)


class SONETAPPLICATIONCODE(Identity):
    """
    Supported SONET/SDH application codes
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:SONET_APPLICATION_CODE"):
        super().__init__(ns, pref, tag)


class OTNAPPLICATIONCODE(Identity):
    """
    Supported OTN application codes
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:OTN_APPLICATION_CODE"):
        super().__init__(ns, pref, tag)


class TRIBUTARYRATECLASSTYPE(Identity):
    """
    Rate of tributary signal \_\- identities will typically reflect
    rounded bit rate.
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TRIBUTARY_RATE_CLASS_TYPE"):
        super().__init__(ns, pref, tag)


class LOGICALELEMENTPROTOCOLTYPE(Identity):
    """
    Type of protocol framing used on the logical channel or
    tributary
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:LOGICAL_ELEMENT_PROTOCOL_TYPE"):
        super().__init__(ns, pref, tag)


class OPTICALCHANNEL(OPENCONFIGHARDWARECOMPONENT):
    """
    Optical channels act as carriers for transport traffic
    directed over a line system.  They are represented as
    physical components in the physical inventory model.
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:OPTICAL_CHANNEL"):
        super().__init__(ns, pref, tag)


class FIBERJUMPERTYPE(Identity):
    """
    Types of fiber jumpers used for connecting device ports
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:FIBER_JUMPER_TYPE"):
        super().__init__(ns, pref, tag)


class OPTICALPORTTYPE(Identity):
    """
    Type definition for optical transport port types
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:OPTICAL_PORT_TYPE"):
        super().__init__(ns, pref, tag)


class AMP(FRAMEMAPPINGPROTOCOL):
    """
    Asynchronous Mapping Procedure
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:AMP"):
        super().__init__(ns, pref, tag)


class GMP(FRAMEMAPPINGPROTOCOL):
    """
    Generic Mapping Procedure
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:GMP"):
        super().__init__(ns, pref, tag)


class BMP(FRAMEMAPPINGPROTOCOL):
    """
    Bit\-synchronous Mapping Procedure
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:BMP"):
        super().__init__(ns, pref, tag)


class CBR(FRAMEMAPPINGPROTOCOL):
    """
    Constant Bit Rate Mapping Procedure
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:CBR"):
        super().__init__(ns, pref, tag)


class GFPT(FRAMEMAPPINGPROTOCOL):
    """
    Transparent Generic Framing Protocol
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:GFP_T"):
        super().__init__(ns, pref, tag)


class GFPF(FRAMEMAPPINGPROTOCOL):
    """
    Framed\-Mapped Generic Framing Protocol
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:GFP_F"):
        super().__init__(ns, pref, tag)


class TRIBSLOT1DOT25G(TRIBUTARYSLOTGRANULARITY):
    """
    The tributary slot with a bandwidth of approximately 1.25 Gb/s
    as defined in ITU\-T G.709 standard.
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TRIB_SLOT_1.25G"):
        super().__init__(ns, pref, tag)


class TRIBSLOT2DOT5G(TRIBUTARYSLOTGRANULARITY):
    """
    The tributary slot with a bandwidth of approximately 2.5 Gb/s
    as defined in ITU\-T G.709 standard.
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TRIB_SLOT_2.5G"):
        super().__init__(ns, pref, tag)


class TRIBSLOT5G(TRIBUTARYSLOTGRANULARITY):
    """
    The tributary slot with a bandwidth of approximately 5 Gb/s
    as defined in ITU\-T G.709 standard.
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TRIB_SLOT_5G"):
        super().__init__(ns, pref, tag)


class PROT1GE(TRIBUTARYPROTOCOLTYPE):
    """
    1G Ethernet protocol
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:PROT_1GE"):
        super().__init__(ns, pref, tag)


class PROTOC48(TRIBUTARYPROTOCOLTYPE):
    """
    OC48 protocol
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:PROT_OC48"):
        super().__init__(ns, pref, tag)


class PROTSTM16(TRIBUTARYPROTOCOLTYPE):
    """
    STM 16 protocol
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:PROT_STM16"):
        super().__init__(ns, pref, tag)


class PROT10GELAN(TRIBUTARYPROTOCOLTYPE):
    """
    10G Ethernet LAN protocol
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:PROT_10GE_LAN"):
        super().__init__(ns, pref, tag)


class PROT10GEWAN(TRIBUTARYPROTOCOLTYPE):
    """
    10G Ethernet WAN protocol
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:PROT_10GE_WAN"):
        super().__init__(ns, pref, tag)


class PROTOC192(TRIBUTARYPROTOCOLTYPE):
    """
    OC 192 (9.6GB) port protocol
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:PROT_OC192"):
        super().__init__(ns, pref, tag)


class PROTSTM64(TRIBUTARYPROTOCOLTYPE):
    """
    STM 64 protocol
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:PROT_STM64"):
        super().__init__(ns, pref, tag)


class PROTOTU2(TRIBUTARYPROTOCOLTYPE):
    """
    OTU 2 protocol
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:PROT_OTU2"):
        super().__init__(ns, pref, tag)


class PROTOTU2E(TRIBUTARYPROTOCOLTYPE):
    """
    OTU 2e protocol
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:PROT_OTU2E"):
        super().__init__(ns, pref, tag)


class PROTOTU1E(TRIBUTARYPROTOCOLTYPE):
    """
    OTU 1e protocol
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:PROT_OTU1E"):
        super().__init__(ns, pref, tag)


class PROTODU2(TRIBUTARYPROTOCOLTYPE):
    """
    ODU 2 protocol
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:PROT_ODU2"):
        super().__init__(ns, pref, tag)


class PROTODU2E(TRIBUTARYPROTOCOLTYPE):
    """
    ODU 2e protocol
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:PROT_ODU2E"):
        super().__init__(ns, pref, tag)


class PROT40GE(TRIBUTARYPROTOCOLTYPE):
    """
    40G Ethernet port protocol
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:PROT_40GE"):
        super().__init__(ns, pref, tag)


class PROTOC768(TRIBUTARYPROTOCOLTYPE):
    """
    OC 768 protocol
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:PROT_OC768"):
        super().__init__(ns, pref, tag)


class PROTSTM256(TRIBUTARYPROTOCOLTYPE):
    """
    STM 256 protocol
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:PROT_STM256"):
        super().__init__(ns, pref, tag)


class PROTOTU3(TRIBUTARYPROTOCOLTYPE):
    """
    OTU 3 protocol
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:PROT_OTU3"):
        super().__init__(ns, pref, tag)


class PROTODU3(TRIBUTARYPROTOCOLTYPE):
    """
    ODU 3 protocol
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:PROT_ODU3"):
        super().__init__(ns, pref, tag)


class PROT100GE(TRIBUTARYPROTOCOLTYPE):
    """
    100G Ethernet protocol
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:PROT_100GE"):
        super().__init__(ns, pref, tag)


class PROT100GMLG(TRIBUTARYPROTOCOLTYPE):
    """
    100G MLG protocol
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:PROT_100G_MLG"):
        super().__init__(ns, pref, tag)


class PROTOTU4(TRIBUTARYPROTOCOLTYPE):
    """
    OTU4 signal protocol (112G) for transporting
    100GE signal
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:PROT_OTU4"):
        super().__init__(ns, pref, tag)


class PROTOTUCN(TRIBUTARYPROTOCOLTYPE):
    """
    OTU Cn protocol
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:PROT_OTUCN"):
        super().__init__(ns, pref, tag)


class PROTODUCN(TRIBUTARYPROTOCOLTYPE):
    """
    ODU Cn protocol
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:PROT_ODUCN"):
        super().__init__(ns, pref, tag)


class PROTODU4(TRIBUTARYPROTOCOLTYPE):
    """
    ODU 4 protocol
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:PROT_ODU4"):
        super().__init__(ns, pref, tag)


class CFP(TRANSCEIVERFORMFACTORTYPE):
    """
    C form\-factor pluggable, that can support up to a
    100 Gb/s signal with 10x10G or 4x25G physical channels
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:CFP"):
        super().__init__(ns, pref, tag)


class CFP2(TRANSCEIVERFORMFACTORTYPE):
    """
    1/2 C form\-factor pluggable, that can support up to a
    200 Gb/s signal with 10x10G, 4x25G, or 8x25G physical
    channels
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:CFP2"):
        super().__init__(ns, pref, tag)


class CFP2ACO(TRANSCEIVERFORMFACTORTYPE):
    """
    CFP2 analog coherent optics transceiver, supporting
    100 Gb, 200Gb, and 250 Gb/s signal.
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:CFP2_ACO"):
        super().__init__(ns, pref, tag)


class CFP4(TRANSCEIVERFORMFACTORTYPE):
    """
    1/4 C form\-factor pluggable, that can support up to a
    100 Gb/s signal with 10x10G or 4x25G physical channels
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:CFP4"):
        super().__init__(ns, pref, tag)


class QSFP(TRANSCEIVERFORMFACTORTYPE):
    """
    OriginalQuad Small Form\-factor Pluggable transceiver that can
    support 4x1G physical channels.  Not commonly used.
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:QSFP"):
        super().__init__(ns, pref, tag)


class QSFPPLUS(TRANSCEIVERFORMFACTORTYPE):
    """
    Quad Small Form\-factor Pluggable transceiver that can support
    up to 4x10G physical channels.
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:QSFP_PLUS"):
        super().__init__(ns, pref, tag)


class QSFP28(TRANSCEIVERFORMFACTORTYPE):
    """
    QSFP pluggable optic with support for up to 4x28G physical
    channels
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:QSFP28"):
        super().__init__(ns, pref, tag)


class CPAK(TRANSCEIVERFORMFACTORTYPE):
    """
    Cisco CPAK transceiver supporting 100 Gb/s.
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:CPAK"):
        super().__init__(ns, pref, tag)


class SFP(TRANSCEIVERFORMFACTORTYPE):
    """
    Small form\-factor pluggable transceiver supporting up to
    10 Gb/s signal
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:SFP"):
        super().__init__(ns, pref, tag)


class SFPPLUS(TRANSCEIVERFORMFACTORTYPE):
    """
    Enhanced small form\-factor pluggable transceiver supporting
    up to 16 Gb/s signals, including 10 GbE and OTU2
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:SFP_PLUS"):
        super().__init__(ns, pref, tag)


class XFP(TRANSCEIVERFORMFACTORTYPE):
    """
    10 Gigabit small form factor pluggable transceiver supporting
    10 GbE and OTU2
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:XFP"):
        super().__init__(ns, pref, tag)


class X2(TRANSCEIVERFORMFACTORTYPE):
    """
    10 Gigabit small form factor pluggable transceiver supporting
    10 GbE using a XAUI inerface and 4 data channels.
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:X2"):
        super().__init__(ns, pref, tag)


class NONPLUGGABLE(TRANSCEIVERFORMFACTORTYPE):
    """
    Represents a port that does not require a pluggable optic,
    e.g., with on\-board optics like COBO
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:NON_PLUGGABLE"):
        super().__init__(ns, pref, tag)


class OTHER(TRANSCEIVERFORMFACTORTYPE):
    """
    Represents a transceiver form factor not otherwise listed
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:OTHER"):
        super().__init__(ns, pref, tag)


class SCCONNECTOR(FIBERCONNECTORTYPE):
    """
    SC type fiber connector
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:SC_CONNECTOR"):
        super().__init__(ns, pref, tag)


class LCCONNECTOR(FIBERCONNECTORTYPE):
    """
    LC type fiber connector
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:LC_CONNECTOR"):
        super().__init__(ns, pref, tag)


class MPOCONNECTOR(FIBERCONNECTORTYPE):
    """
    MPO (multi\-fiber push\-on/pull\-off) type fiber connector
    1x12 fibers
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:MPO_CONNECTOR"):
        super().__init__(ns, pref, tag)


class ETH10GBASELRM(ETHERNETPMDTYPE):
    """
    Ethernet compliance code\: 10GBASE\_LRM
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:ETH_10GBASE_LRM"):
        super().__init__(ns, pref, tag)


class ETH10GBASELR(ETHERNETPMDTYPE):
    """
    Ethernet compliance code\: 10GBASE\_LR
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:ETH_10GBASE_LR"):
        super().__init__(ns, pref, tag)


class ETH10GBASEZR(ETHERNETPMDTYPE):
    """
    Ethernet compliance code\: 10GBASE\_ZR
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:ETH_10GBASE_ZR"):
        super().__init__(ns, pref, tag)


class ETH10GBASEER(ETHERNETPMDTYPE):
    """
    Ethernet compliance code\: 10GBASE\_ER
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:ETH_10GBASE_ER"):
        super().__init__(ns, pref, tag)


class ETH10GBASESR(ETHERNETPMDTYPE):
    """
    Ethernet compliance code\: 10GBASE\_SR
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:ETH_10GBASE_SR"):
        super().__init__(ns, pref, tag)


class ETH40GBASECR4(ETHERNETPMDTYPE):
    """
    Ethernet compliance code\: 40GBASE\_CR4
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:ETH_40GBASE_CR4"):
        super().__init__(ns, pref, tag)


class ETH40GBASESR4(ETHERNETPMDTYPE):
    """
    Ethernet compliance code\: 40GBASE\_SR4
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:ETH_40GBASE_SR4"):
        super().__init__(ns, pref, tag)


class ETH40GBASELR4(ETHERNETPMDTYPE):
    """
    Ethernet compliance code\: 40GBASE\_LR4
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:ETH_40GBASE_LR4"):
        super().__init__(ns, pref, tag)


class ETH40GBASEER4(ETHERNETPMDTYPE):
    """
    Ethernet compliance code\: 40GBASE\_ER4
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:ETH_40GBASE_ER4"):
        super().__init__(ns, pref, tag)


class ETH40GBASEPSM4(ETHERNETPMDTYPE):
    """
    Ethernet compliance code\: 40GBASE\_PSM4
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:ETH_40GBASE_PSM4"):
        super().__init__(ns, pref, tag)


class ETH4X10GBASELR(ETHERNETPMDTYPE):
    """
    Ethernet compliance code\: 4x10GBASE\_LR
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:ETH_4X10GBASE_LR"):
        super().__init__(ns, pref, tag)


class ETH4X10GBASESR(ETHERNETPMDTYPE):
    """
    Ethernet compliance code\: 4x10GBASE\_SR
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:ETH_4X10GBASE_SR"):
        super().__init__(ns, pref, tag)


class ETH100GAOC(ETHERNETPMDTYPE):
    """
    Ethernet compliance code\: 100G\_AOC
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:ETH_100G_AOC"):
        super().__init__(ns, pref, tag)


class ETH100GACC(ETHERNETPMDTYPE):
    """
    Ethernet compliance code\: 100G\_ACC
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:ETH_100G_ACC"):
        super().__init__(ns, pref, tag)


class ETH100GBASESR10(ETHERNETPMDTYPE):
    """
    Ethernet compliance code\: 100GBASE\_SR10
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:ETH_100GBASE_SR10"):
        super().__init__(ns, pref, tag)


class ETH100GBASESR4(ETHERNETPMDTYPE):
    """
    Ethernet compliance code\: 100GBASE\_SR4
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:ETH_100GBASE_SR4"):
        super().__init__(ns, pref, tag)


class ETH100GBASELR4(ETHERNETPMDTYPE):
    """
    Ethernet compliance code\: 100GBASE\_LR4
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:ETH_100GBASE_LR4"):
        super().__init__(ns, pref, tag)


class ETH100GBASEER4(ETHERNETPMDTYPE):
    """
    Ethernet compliance code\: 100GBASE\_ER4
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:ETH_100GBASE_ER4"):
        super().__init__(ns, pref, tag)


class ETH100GBASECWDM4(ETHERNETPMDTYPE):
    """
    Ethernet compliance code\: 100GBASE\_CWDM4
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:ETH_100GBASE_CWDM4"):
        super().__init__(ns, pref, tag)


class ETH100GBASECLR4(ETHERNETPMDTYPE):
    """
    Ethernet compliance code\: 100GBASE\_CLR4
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:ETH_100GBASE_CLR4"):
        super().__init__(ns, pref, tag)


class ETH100GBASEPSM4(ETHERNETPMDTYPE):
    """
    Ethernet compliance code\: 100GBASE\_PSM4
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:ETH_100GBASE_PSM4"):
        super().__init__(ns, pref, tag)


class ETH100GBASECR4(ETHERNETPMDTYPE):
    """
    Ethernet compliance code\: 100GBASE\_CR4
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:ETH_100GBASE_CR4"):
        super().__init__(ns, pref, tag)


class ETHUNDEFINED(ETHERNETPMDTYPE):
    """
    Ethernet compliance code\: undefined
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:ETH_UNDEFINED"):
        super().__init__(ns, pref, tag)


class VSR20003R2(SONETAPPLICATIONCODE):
    """
    SONET/SDH application code\: VSR2000\_3R2
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:VSR2000_3R2"):
        super().__init__(ns, pref, tag)


class VSR20003R3(SONETAPPLICATIONCODE):
    """
    SONET/SDH application code\: VSR2000\_3R3
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:VSR2000_3R3"):
        super().__init__(ns, pref, tag)


class VSR20003R5(SONETAPPLICATIONCODE):
    """
    SONET/SDH application code\: VSR2000\_3R5
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:VSR2000_3R5"):
        super().__init__(ns, pref, tag)


class SONETUNDEFINED(SONETAPPLICATIONCODE):
    """
    SONET/SDH application code\: undefined
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:SONET_UNDEFINED"):
        super().__init__(ns, pref, tag)


class P1L12D1(OTNAPPLICATIONCODE):
    """
    OTN application code\: P1L1\_2D1
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:P1L1_2D1"):
        super().__init__(ns, pref, tag)


class P1S12D2(OTNAPPLICATIONCODE):
    """
    OTN application code\: P1S1\_2D2
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:P1S1_2D2"):
        super().__init__(ns, pref, tag)


class P1L12D2(OTNAPPLICATIONCODE):
    """
    OTN application code\: P1L1\_2D2
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:P1L1_2D2"):
        super().__init__(ns, pref, tag)


class OTNUNDEFINED(OTNAPPLICATIONCODE):
    """
    OTN application code\: undefined
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:OTN_UNDEFINED"):
        super().__init__(ns, pref, tag)


class TRIBRATE1G(TRIBUTARYRATECLASSTYPE):
    """
    1G tributary signal rate
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TRIB_RATE_1G"):
        super().__init__(ns, pref, tag)


class TRIBRATE2DOT5G(TRIBUTARYRATECLASSTYPE):
    """
    2.5G tributary signal rate
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TRIB_RATE_2.5G"):
        super().__init__(ns, pref, tag)


class TRIBRATE10G(TRIBUTARYRATECLASSTYPE):
    """
    10G tributary signal rate
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TRIB_RATE_10G"):
        super().__init__(ns, pref, tag)


class TRIBRATE40G(TRIBUTARYRATECLASSTYPE):
    """
    40G tributary signal rate
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TRIB_RATE_40G"):
        super().__init__(ns, pref, tag)


class TRIBRATE100G(TRIBUTARYRATECLASSTYPE):
    """
    100G tributary signal rate
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TRIB_RATE_100G"):
        super().__init__(ns, pref, tag)


class TRIBRATE150G(TRIBUTARYRATECLASSTYPE):
    """
    150G tributary signal rate
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TRIB_RATE_150G"):
        super().__init__(ns, pref, tag)


class TRIBRATE200G(TRIBUTARYRATECLASSTYPE):
    """
    200G tributary signal rate
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TRIB_RATE_200G"):
        super().__init__(ns, pref, tag)


class TRIBRATE250G(TRIBUTARYRATECLASSTYPE):
    """
    250G tributary signal rate
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TRIB_RATE_250G"):
        super().__init__(ns, pref, tag)


class TRIBRATE300G(TRIBUTARYRATECLASSTYPE):
    """
    300G tributary signal rate
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TRIB_RATE_300G"):
        super().__init__(ns, pref, tag)


class TRIBRATE400G(TRIBUTARYRATECLASSTYPE):
    """
    400G tributary signal rate
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TRIB_RATE_400G"):
        super().__init__(ns, pref, tag)


class TRIBRATE500G(TRIBUTARYRATECLASSTYPE):
    """
    500G tributary signal rate
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TRIB_RATE_500G"):
        super().__init__(ns, pref, tag)


class TRIBRATE600G(TRIBUTARYRATECLASSTYPE):
    """
    600G tributary signal rate
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TRIB_RATE_600G"):
        super().__init__(ns, pref, tag)


class TRIBRATE700G(TRIBUTARYRATECLASSTYPE):
    """
    700G tributary signal rate
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TRIB_RATE_700G"):
        super().__init__(ns, pref, tag)


class TRIBRATE800G(TRIBUTARYRATECLASSTYPE):
    """
    800G tributary signal rate
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TRIB_RATE_800G"):
        super().__init__(ns, pref, tag)


class TRIBRATE900G(TRIBUTARYRATECLASSTYPE):
    """
    900G tributary signal rate
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TRIB_RATE_900G"):
        super().__init__(ns, pref, tag)


class TRIBRATE1000G(TRIBUTARYRATECLASSTYPE):
    """
    1000G tributary signal rate
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TRIB_RATE_1000G"):
        super().__init__(ns, pref, tag)


class TRIBRATE1100G(TRIBUTARYRATECLASSTYPE):
    """
    1100G tributary signal rate
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TRIB_RATE_1100G"):
        super().__init__(ns, pref, tag)


class PROTETHERNET(LOGICALELEMENTPROTOCOLTYPE):
    """
    Ethernet protocol framing
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:PROT_ETHERNET"):
        super().__init__(ns, pref, tag)


class PROTOTN(LOGICALELEMENTPROTOCOLTYPE):
    """
    OTN protocol framing
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:PROT_OTN"):
        super().__init__(ns, pref, tag)


class FIBERJUMPERSIMPLEX(FIBERJUMPERTYPE):
    """
    Simplex fiber jumper
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:FIBER_JUMPER_SIMPLEX"):
        super().__init__(ns, pref, tag)


class FIBERJUMPERMULTIFIBERSTRAND(FIBERJUMPERTYPE):
    """
    One strand of a fiber jumper which contains multiple fibers
    within it, such as an MPO based fiber jumper
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:FIBER_JUMPER_MULTI_FIBER_STRAND"):
        super().__init__(ns, pref, tag)


class INGRESS(OPTICALPORTTYPE):
    """
    Ingress port, corresponding to a signal entering
    a line system device such as an amplifier or wavelength
    router.
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:INGRESS"):
        super().__init__(ns, pref, tag)


class EGRESS(OPTICALPORTTYPE):
    """
    Egress port, corresponding to a signal exiting
    a line system device such as an amplifier or wavelength
    router.
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:EGRESS"):
        super().__init__(ns, pref, tag)


class ADD(OPTICALPORTTYPE):
    """
    Add port, corresponding to a signal injected
    at a wavelength router.
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:ADD"):
        super().__init__(ns, pref, tag)


class DROP(OPTICALPORTTYPE):
    """
    Drop port, corresponding to a signal dropped
    at a wavelength router.
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:DROP"):
        super().__init__(ns, pref, tag)


class MONITOR(OPTICALPORTTYPE):
    """
    Monitor port, corresponding to a signal used by an optical
    channel monitor. This is used to represent the connection
    that a channel monitor port is connected to, typically on a
    line system device. This  connection may be via physical cable
    and faceplate ports or internal to the device
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:MONITOR"):
        super().__init__(ns, pref, tag)


class TERMINALCLIENT(OPTICALPORTTYPE):
    """
    Client\-facing port on a terminal optics device (e.g.,
    transponder or muxponder).
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TERMINAL_CLIENT"):
        super().__init__(ns, pref, tag)


class TERMINALLINE(OPTICALPORTTYPE):
    """
    Line\-facing port on a terminal optics device (e.g.,
    transponder or muxponder).
    
    """
    _prefix = 'oc-opt-types'
    _revision = '2019-06-27'

    def __init__(self, ns="http://openconfig.net/yang/transport-types", pref="openconfig-transport-types", tag="openconfig-transport-types:TERMINAL_LINE"):
        super().__init__(ns, pref, tag)



